#!/bin/bash
#
# Create a post pointing out a change in the website.  Use carefully,
# this is just meant to save some typing, and it might not fit into
# your layout without a bit of tweaking.
#
# From the announcements directory
# usage: script/post.sh <dir> <index> [<note>]
# where <dir> is one of hwk, lec, rec, lab, exam;
# <index> is an integer; and <note> is an optional explaination.
#
# For example,
#   script/post.sh rec 2 solutions
# points out the posting of Recitation 2 solutions, and targets the URL
#   $COURSE_WEBSITE/recitations.shtml#s2

. script/course-details.sh

if [ "$#" -lt 2 ]; then
    echo "usage: script/post.sh <dir> <index> [<note>]"
    exit 1
fi

DIR="$1"
INDEX="$2"
NOTE="$3"

if [ -n "$NOTE" ] && [ "${NOTE:0:1}" != " " ]; then
    NOTE=" $NOTE" # ensure leading space
fi

if [ "$DIR" == "hwk" ]; then
    NAME="Homework"
    PAGE="homeworks.shtml"
elif [ "$DIR" == "lec" ]; then
    NAME="Lecture"
    PAGE="lectures.shtml"
elif [ "$DIR" == "rec" ]; then
    NAME="Recitation"
    PAGE="recitations.shtml"
elif [ "$DIR" == "lab" ]; then
    NAME="Lab"
    PAGE="labs.shtml"
elif [ "$DIR" == "exam" ]; then
    NAME="Exam"
    PAGE="exams.shtml"
else
    echo "Unrecognized dir '$DIR'"
    exit 1
fi

echo "echo \"$NAME $INDEX$NOTE posted.\" | \\
    atomgen -o atom.xml add -i atom.xml \"$NAME $INDEX$NOTE posted.\" \\
    \"$COURSE_WEBSITE/$PAGE#s$INDEX\""
echo "$NAME $INDEX$NOTE posted." | \
    atomgen -o atom.xml add -i atom.xml "$NAME $INDEX$NOTE posted." \
    "$COURSE_WEBSITE/$PAGE#s$INDEX"
